@@ -8,25 +8,29 @@
 #include <libwnck/libwnck.h>
 
 typedef struct _dockapp {
- WnckWindow *w;
- GtkSocket *s;
+ GtkSocket       *s;
  GdkNativeWindow i;
- gchar *name;
- gchar *cmd;
+ GtkWidget       *bg;
+ GtkWidget       *tile;
+ gchar           *name;
+ gchar           *cmd;
 } DockappNode;
 
 typedef struct {
  XfcePanelPlugin *plugin;
 
- GtkWidget *ebox;
+ GtkWidget       *eventBox;
 	
  /* Plugin specific definitions */
- GtkWidget *align;
- GtkWidget *box;
+ GtkWidget       *align;
+ GtkWidget       *box;
+ GtkWidget       *panelBox;
 	
- gboolean propDispTile;
+ gboolean        propDispTile;
+ gboolean        propDispPropButton;
+ gboolean        propDispAddOnlyWM;
 
- GList *dapps;
+ GList           *dapps;
 } WmdockPlugin;
 
 #endif /* __WMDOCK_H__ */
